==> haskell-xdg-desktop-entry-0.1.1.2-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-3quJUWHUOKYJau0efiyUTA
key:                  xdg-desktop-entry-0.1.1.2-3quJUWHUOKYJau0efiyUTA
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  f596787a14ab2d51477861931eb78bf6
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-3quJUWHUOKYJau0efiyUTA
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.3-3Cpa4QU2PcuJ7IDGatAF0h
    filepath-1.4.2.2 ini-0.4.2-DmD4Egzo7Vo5LwdzjQDYPs
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-3kF9VX2rOl78iX2OdZTXNo text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-1s4f8pAJmee27mGfYrIk99

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-desktop-entry-0.1.1.2-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-CkQCM3DneFs3gkDXsV32JZ
key:                  xdg-desktop-entry-0.1.1.2-CkQCM3DneFs3gkDXsV32JZ
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  617d3551b5d6b562d8a817ff44587709
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-CkQCM3DneFs3gkDXsV32JZ
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.3-6Yv9aYC5RunDrOwefPnrne
    filepath-1.4.2.2 ini-0.4.2-91QYlmTGiHJDx8MXncjhXv
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-HlwzjIK5TiIKPzF0RtoFLn text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-Jnp6Xrk1NDm4qrPXFyeyaF

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
